pub(super) struct ElementalConfig {Show 19 fields
pub supercharge_chance: f64,
pub feedback_loop_chance: f64,
pub fusion_of_elements_mult: f64,
pub eb_overload_mult: f64,
pub aftershock_chance: f64,
pub potm_chance: f64,
pub stormwell_tempest_maelstrom: f64,
pub tempest_chance_on_blast: f64,
pub eb_overload: bool,
pub master_of_the_elements: bool,
pub arc_discharge: bool,
pub unlimited_power: bool,
pub lightning_rod_mult: f64,
pub summon_storm_elemental: bool,
pub summon_fire_elemental: bool,
pub tww3_stormbringer_2pc: bool,
pub tww3_stormbringer_4pc: bool,
pub mid1_2pc: bool,
pub mid1_4pc: bool,
}Fields
supercharge_chance: f64Supercharge effect proc chance.
feedback_loop_chance: f64Feedback Loop rank-three bonus chance.
fusion_of_elements_mult: f64Fusion of Elements effect damage fraction.
eb_overload_mult: f64Mountains Will Fall Elemental Blast overload fraction.
aftershock_chance: f64Aftershock effect refund chance.
potm_chance: f64Power of the Maelstrom effect proc chance.
stormwell_tempest_maelstrom: f64Live bug: Tempest applying a NEW Stormkeeper via Arc Discharge triggers Stormwell’s Maelstrom grant (sc_shaman.cpp:9686, bugs=1).
tempest_chance_on_blast: f64Tempest and Awakening Storms per-point chances folded across Elemental Blast cost.
eb_overload: boolMountains Will Fall enables Elemental Blast overloads.
master_of_the_elements: boolMaster of the Elements enables its spender window.
arc_discharge: boolArc Discharge enables its overload rider.
unlimited_power: boolUnlimited Power enables haste stacking.
lightning_rod_mult: f64Lightning Rod effect damage fraction.
summon_storm_elemental: boolFury of the Storms plus Primal Elementalist enables the primal Storm Elemental.
summon_fire_elemental: boolCall of Fire plus Primal Elementalist enables the primal Fire Elemental.
tww3_stormbringer_2pc: boolTWW3 Stormbringer two-piece grants Tempest on Ascendance (sc_shaman.cpp:11141).
tww3_stormbringer_4pc: boolTWW3 Stormbringer four-piece enables its tier rider.
mid1_2pc: boolMID1 Elemental two-piece enables its tier rider.
mid1_4pc: boolMID1 Elemental four-piece enables its tier rider.